gchecky.model.anonymous_address_t

Package gchecky :: Module model :: Class anonymous_address_t |
[hide private]
[frames] | no frames]

# Class anonymous_address_t

source code

    object --+
             |
     gxml.Node --+
                 |
                anonymous_address_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| id = `String:PATH(@id):REQ:EMPTY`
| city = `String:PATH(city):REQ:EMPTY`
| region = `String:PATH(region):REQ:EMPTY`
| postal_code = `Zip:PATH(postal-code):REQ:EMPTY`
| country_code = `String:PATH(country-code):REQ:EMPTY`
| _fields = ``{``'``city``'``:` String:PATH(city):REQ:EMPTY`,` `'``country_code``'``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'city': String:PATH(city):REQ:EMPTY,
       'country_code': String:PATH(country-code):REQ:EMPTY,
       'id': String:PATH(@id):REQ:EMPTY,
       'postal_code': Zip:PATH(postal-code):REQ:EMPTY,
       'region': String:PATH(region):REQ:EMPTY}